import React, { useState, useEffect, useCallback, useMemo } from 'react'
import { useSelector } from 'react-redux';
import axios from 'axios'
import { toast } from 'react-toastify';
import { getEndpointBaseURL } from '@services/environment';
import { capitalCase } from '@services/shared';
import getHeaders from '@services/headersService';

import Products from './visualization-menu-config/product/product'
import Info from './visualization-menu-config/info/info'
import StartOver from './visualization-menu-config/startOver/startOver'
import RoomMenuInfo from './visualization-menu-config/room-menu-info/room-menu-info'
import VisualizationRoomWindow from './visualization-room-window/visualization-room-window'
import ColorOption from './visualization-menu-config/color-option/color-option'
import ShareProject from './visualization-menu-config/shareProject/share-project'
import VisualizationCompare from './visualization-compare/visualization-compare'
import SideMenu from './side-menu/side-menu'
import StepNav from './step-nav/step-nav'
import RoomHouseEditHelp from './visualization-menu-config/room-house-edit-help/room-house-edit-help';
import RoomInMyHouseContainer from './room-in-my-house/room-in-my-house';

import MenuImage from '../../../assets/images/Visualizers-images/menu-image.svg'
import ProductImage from '../../../assets/images/Visualizers-images/menu-product.png'
import ColorImage from '../../../assets/images/Visualizers-images/menu-colors.png'
import OptionImage from '../../../assets/images/Visualizers-images/menu-options.png'
import InfoImage from '../../../assets/images/Visualizers-images/menu-info.png'
import StartOverImage from '../../../assets/images/Visualizers-images/menu-start-over.png'
import CloseIcon from '../../../assets/images/Visualizers-images/close-icon.svg'
import helpIcon from '../../../assets/images/Visualizers-images/help.svg'
//####### Room In My House ########//
import VisualizeImage from '../../../assets/images/roominmyhouse/png/visualize.png'

import './visualization-container.scss'

const VisualizationContainer = ({ startOver, retrieveSession }) => {
  const CONFIG_STEPS = {
    MENU_INFO: 1,
    PRODUCTS: 2,
    COLORS: 3,
    OPTIONS: 4,
    INFO: 5,
    START_OVER: 6,
    SHARE_YOUR_PROJECT: 7,
    BACK_TO: 7,
    SELECTED_ROOM: 8
  }

  const OPTION_TYPE = {
    COLOR: 1,
    OPTION: 2
  };

  const sampleRoomDetails = useSelector((state) => state.savedProjects.sampleRoom);
  let menuToRender = []
  if(!sampleRoomDetails?.room_in_house){
    menuToRender = CONFIG_STEPS.PRODUCTS;
  }
  const [isShowOptionConfigModal, setIsShowOptionConfigModal] = useState(true)
  const [menuCurrentView, setMenuCurrentView] = useState(menuToRender)
  const [isCompareView, setIsCompareView] = useState(false)
  const [isFullScreen, setIsFullScreen] = useState(false)
  const [isRoomInHouse, setIsRoomInHouse] = useState(undefined)

  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  const savedSceneDetails = useSelector((state) => state.savedScene);

  const escFunction = useCallback((event) => {
    if (event.key === "Escape") {
      setIsFullScreen(false)
    }
  }, []);


  useEffect(() => {
    document.addEventListener("keydown", escFunction, false);
    return () => {
      document.removeEventListener("keydown", escFunction, false);
    };
  }, [escFunction]);

  useEffect(() => {
    if(sampleRoomDetails.room_in_house){
      setMenuCurrentView(CONFIG_STEPS.ROOM_IN_MY_HOUSE)
      setIsRoomInHouse(sampleRoomDetails.room_in_house)
    }
  }, [sampleRoomDetails.room_in_house])

  const roomMenuList = [
    {
      id: 1,
      name: 'Menu',
      icon: MenuImage
    },
    {
      id: 2,
      name: 'Products',
      icon: ProductImage
    },
    {
      id: 3,
      name: 'Colors',
      icon: ColorImage
    },
    {
      id: 4,
      name: 'Options',
      icon: OptionImage
    },
    {
      id: 5,
      name: 'Info',
      icon: InfoImage
    },
    {
      id: 6,
      name: 'Start Over',
      icon: StartOverImage
    },
    // {
    //   id: 7,
    //   name: 'Collaborate on a project',
    //   icon: ''
    // }
  ]

  const compareMenuList = [
    {
      id: 10,
      name: 'Back',
      icon: helpIcon
    },
    {
      id: 6,
      name: 'Start Over',
      icon: StartOverImage
    }
  ]

  const roomInMyHouseList = [
    {
      id: 11,
      name: 'Edit Help',
      icon: 'https://visualization.graberblinds.com/assets/graphics/help.svg'
    },
    {
      id: 12,
      name: 'Visualize',
      icon: VisualizeImage
    },
    {
      id: 6,
      name: 'Start Over',
      icon: StartOverImage
    }
  ]
  const closeModalHandler = () => {
    setIsShowOptionConfigModal(!isShowOptionConfigModal)
  }

  const takeBackHandler = () => {
    setIsShowOptionConfigModal(!isShowOptionConfigModal)
    setMenuCurrentView(CONFIG_STEPS.PRODUCTS)
  }

  const onMenuSelectHandler = menu => {
    const setMenuName = menu.id === 11
    ? CONFIG_STEPS.ROOM_IN_MY_HOUSE
    : menu.id === 12 
    ? CONFIG_STEPS.PRODUCTS
    : menu.id
    setMenuCurrentView(setMenuName)
    if (menu.id === 12) {
      setIsRoomInHouse(!isRoomInHouse)
    }
    // setMenuCurrentView(menu.id)
    if (menu.name === 'Back') {
      setIsCompareView(false)
      takeBackHandler()
    }
    if (menu.name !== 'Start Over') {
      setIsShowOptionConfigModal(!isShowOptionConfigModal)
    } else {
      savedSceneDetails.currentScene?.deleteAllBlindDetails();
      setIsShowOptionConfigModal(false)
    }
  }

  const nextViewHandler = (next) => {
    if (menuCurrentView !== CONFIG_STEPS.INFO && next) {
      setMenuCurrentView(menuCurrentView + 1)
    } else if(!next) {
      setMenuCurrentView(menuCurrentView - 1)
    }
    if (menuCurrentView === CONFIG_STEPS.INFO && next) {
      // onPDFDownload()
    }
  }

  const onPDFDownload = async () => {
    const { color: colors, product_name: ProductName, ...Options } = defaultProduct;
    let colorItem = {}
    if(colors !== undefined){
      const {color_name: colorName, color_number: colorNumber, color_style: colorStyle} = colors;
      colorItem = {
        "Color Name": colorName,
        "Color Number": colorNumber,
        "Color Style": colorStyle,
      }
    }

    const unusedOptionsItem = [
      "createdAt", "curtain_image_name", "curtain_image_path", "openingOption",
      "product_image_name", "product_image_path", "status", "updatedAt", "id",
      "shades/Window", "ar_model_name", "ar_model_url"
    ]

    let optionItems = {};
    for(let x in Options){
      unusedOptionsItem.includes(x) ? delete Options.x : optionItems[capitalCase(x)] = Options[x]
    }

    const formData = new FormData();
    
    formData.append('productModel', ProductName);
    formData.append('options', JSON.stringify(optionItems));
    formData.append('colorOption', JSON.stringify(colorItem));
    formData.append('estimatedWindowSizes', sampleRoomDetails?.window_estimate_size);
    formData.append('sampleroomId', sampleRoomDetails?.id);
    formData.append('sampleRoomImage', savedSceneDetails.currentScene.saveAsImage('pdfImageUrl'));
    
    await axios.post(getEndpointBaseURL() + 'generatePdfApi/1', formData, { headers: getHeaders('multipart/form-data')})
      .then(res => {
        const pdfBlob = new Blob([res.data], { type: 'application/pdf' });
        const _url = window.URL.createObjectURL(pdfBlob);
        window.open(_url, '_blank');
        toast.success('Downloaded pdf successfully', {
          position: "top-right",
          hideProgressBar: false,
          theme: "colored"
        });
      }).catch(error => {
        toast.error('Failed to download pdf: ' + error.message, {
          position: "top-right",
          hideProgressBar: false,
          theme: "colored"
        });
      });
  }

  const openCompareHandler = () => {
    setIsCompareView(!isCompareView)
    setIsShowOptionConfigModal(false)
  }

  const shareProjectHandler = menu => {
    setMenuCurrentView(menu.id)
    setIsShowOptionConfigModal(true)
  }
  const showCompareDetails = item => {
    setMenuCurrentView(8)
    setIsShowOptionConfigModal(!isShowOptionConfigModal)
  }

  const onFullScreenHandler = () => {
    setIsFullScreen(!isFullScreen)
  }

  const productsComponent = useMemo(() => <Products />, []);
  const colorOptionComponent = useMemo(() => <ColorOption optionType={OPTION_TYPE.COLOR} />, []);
  const optionComponent = useMemo(() => <ColorOption optionType={OPTION_TYPE.OPTION} />, []);
  const infoComponent = useMemo(() => <Info />, []);

  return (
      <div className={`visualization-container ${
            isFullScreen && 'full-screen'
          } ${ isShowOptionConfigModal && 'open-config-container' }`}>
        {sampleRoomDetails && defaultProduct && !isCompareView && !isRoomInHouse &&
          <VisualizationRoomWindow
            showCompare={openCompareHandler}
            onFullScreen={onFullScreenHandler}
          />
        }

        {isRoomInHouse && 
          <RoomInMyHouseContainer
            imageData={sampleRoomDetails.live_path}
            onFullScreen={onFullScreenHandler}
          />
        }

        {isCompareView && (
          <VisualizationCompare
            onFullScreen={onFullScreenHandler}
            onSelect={item => showCompareDetails(item)}
          />
        )}

        <SideMenu
          menuList={
            (
              !isCompareView && !isRoomInHouse)
              ? roomMenuList
              : (
                !isRoomInHouse
                ? compareMenuList
                : roomInMyHouseList
                )
          }
          onMenuSelect={menu => onMenuSelectHandler(menu)}
        />
        
        <div
          className={`visualization-config-container ${
            isShowOptionConfigModal && 'open'
          }`}
        >
          {isShowOptionConfigModal && (
            <>
              <StepNav
                isNextShow={
                  menuCurrentView !== CONFIG_STEPS.MENU_INFO &&
                  menuCurrentView !== CONFIG_STEPS.MENU_INFO
                }
                next={() => nextViewHandler('next')}
                back={() => nextViewHandler()}
                prev={() => closeModalHandler()}
                isSharedProject={
                  menuCurrentView === CONFIG_STEPS.SHARE_YOUR_PROJECT
                    ? true
                    : false
                }
                isRoomInMyHouseBtn={
                  menuCurrentView === CONFIG_STEPS.ROOM_IN_MY_HOUSE
                    ? true
                    : false
                }
                nextBtnLabel={`${
                  menuCurrentView === CONFIG_STEPS.INFO
                    ? 'Product Sheet'
                    : menuCurrentView === CONFIG_STEPS.SHARE_YOUR_PROJECT
                    ? 'Collaborate on a project'
                    : menuCurrentView === CONFIG_STEPS.ROOM_IN_MY_HOUSE
                    ? 'Identify Windows'
                    : `Next: ${roomMenuList[menuCurrentView]?.name}`
                }`}
                prevBtnLabel={
                  <img className='close-icon' src={CloseIcon} alt='' />
                }
                backBtn={[3,4,5].includes(menuCurrentView)}
              ></StepNav>

              <div className='items'>
                {menuCurrentView === CONFIG_STEPS.MENU_INFO && (
                  <RoomMenuInfo
                    productName={defaultProduct.product_name}
                    openShareProject={() =>
                      shareProjectHandler({
                        id: 7,
                        name: 'Collaborate on a project'
                      })
                    }
                  />
                )}

                {menuCurrentView === CONFIG_STEPS.SHARE_YOUR_PROJECT && (
                  <ShareProject
                    retrieveSession={retrieveSession}
                    currentView={setMenuCurrentView}
                  />
                )}

                {(menuCurrentView === CONFIG_STEPS.PRODUCTS) && (productsComponent)}
                {menuCurrentView === CONFIG_STEPS.COLORS && (colorOptionComponent)}
                {menuCurrentView === CONFIG_STEPS.OPTIONS && (optionComponent)}
                {menuCurrentView === CONFIG_STEPS.INFO && (infoComponent)}
                {menuCurrentView === CONFIG_STEPS.SELECTED_ROOM && (infoComponent)}
              </div>
            </>
          )}
          {
            menuCurrentView === CONFIG_STEPS.ROOM_IN_MY_HOUSE && isRoomInHouse && (
              <RoomHouseEditHelp
                openVisualizer={() => onMenuSelectHandler({
                  id: 12,
                  name: 'Visualize'
                })
                }
              />
            )
          }
        </div>

        {menuCurrentView === CONFIG_STEPS.START_OVER && (
          <StartOver takeBack={takeBackHandler} startOver={startOver} isShow={menuCurrentView === CONFIG_STEPS.START_OVER} />
        )}
      </div>
  )
}

export default VisualizationContainer
