import { useEffect, useState } from "react"
import { Button, Modal } from "react-bootstrap";
import axios from 'axios';

import okImg from '@assets/images/ok.svg'

import { generateRandomCode } from "../../../../../utils/helper-functions";
import getIPAddress from "@services/getIPAddress";
import LocalStorage from "@services/local-storage";
import { sharableLink } from "../../../../../constants/projectConstants";
import { getEndpointBaseURL } from "@services/environment";

import './retrieve-modal.scss'

const ShareScene = (props) => {
  const [ip, setIp] = useState('')
  const [code, setCode] = useState('')

  const copyCode = () => {
    try {
      const elemToCopy = document.getElementById('cpLink').innerText;
      return window.navigator.clipboard.writeText(elemToCopy);
    } catch (error) {
      console.log("Couldn't copy the text")
    }
  }

  const shareSceneData =  async (ip, code) => {
    try {
      const getLocalData = LocalStorage.get('savedProjects');
      const len = getLocalData.length;
      // eslint-disable-next-line array-callback-return
      const getLastItem = getLocalData.filter((item, key) => {
          if(key === (len-1)){
              return item;
          }
      })
      const data = {
          'ipaddress': ip,
          'session_data': getLastItem[0],
          'code': code,
          'url': sharableLink + code
      }
      // console.log('data', data)
      if(ip && code) {
        const response = await axios.post(getEndpointBaseURL() + 'shareScene', data)
        if(response.data.status === 200) {
          console.log('Share scene successful')
        }
      }
    } catch (error) {
      console.log('share scene error', error)
    }
  }
  
  useEffect(() => {
    setCode(generateRandomCode())
    getIPAddress().then(res => {
      setIp(res.ip)
    })
  }, [])

  useEffect(() => {
    if(ip !== '' && code !== '') {
      shareSceneData(ip, code)
    }
  }, [ip, code])

  return (
        <Modal
          {...props}
          backdrop="static"
          keyboard={false}
          aria-labelledby="contained-modal-title-vcenter"
        >
          <Modal.Header closeButton>
            <Modal.Title id="contained-modal-title-vcenter">
              <h2>Your shareable scene</h2>
            </Modal.Title>
          </Modal.Header>
          <Modal.Body className="grid-example scrollable-body">
            <h3>The code to retrieve this scene on a different device is:</h3>
            <br />
            <p className="fs-5 fw-bolder">{code}</p>
            <br />
            <h3>Alternatively, use the following link:</h3>
            <br />
            <h1 id="cpLink" className="fs-5 fw-bolder">{ `${sharableLink + code}` }</h1>
            <br />
            <div className="float-end text-decoration-underline cursor-style" onClick={copyCode}>Copy URL to Clipboard</div>
            <br />
            <div className="pt-5">
              <p>The recipient has 2 days to retrieve the scene before it expires.</p>
            </div>
          </Modal.Body>
          <Modal.Footer>
            
            <span role="button" onClick={props.onHide} className="alignItem">
              <img className="ok recolour-icons" src={okImg} alt="" />
              <Button className="text-decoration-underline" variant="none">Ok</Button>
            </span>
          </Modal.Footer>
        </Modal>
      );
}

export default ShareScene