import React, { useState, useEffect } from "react";
import { Button } from "react-bootstrap";
import VisualisarImg from "../../../assets/images/cover.jpg"
import SampleRoom from "../../../assets/images/icon-sample-room.png"
import RoomInHouse from "../../../assets/images/icon-room-in-my-house.png"
import HeartFillImg from "../../../assets/images/intro_menu_heart_fill.png"

import SampleRoomInfoModal from './sample-room-info-modal/sample-room-info-modal'
import RoomInMyHouseUpload from "./room-in-my-house-upload/room-in-my-house-upload";
import LocalStorage from '@services/local-storage';

import "./visualization-options.scss";

const initialList = [
  { id: 'SAMPLE_ROOM', name: 'Sample Rooms', icon: SampleRoom, isDisable: false },
  { id: 'ROOM_IN_HOUSE', name: 'Room In My House', icon: RoomInHouse, isDisable: false },
  { id: 'SAVED_PROJECTS', name: 'Saved Projects', icon: HeartFillImg, isDisable: true }
];

function VisualizationOptions(props) {
  const [isFromSavedProjects, setIsFromSavedProjects] = useState(false);
  const [modalTitle, setModalTitle] = useState('');
  const [showSampleRoomInfoModal, setShowSampleRoomInfoModal] = useState(false);
  const [optionsDetails, setOptionsDetails] = useState(initialList);
  const [showFileUpload, setShowFileUpload] = useState(false);

  useEffect(() => {
    const parseData = LocalStorage.get('savedProjects');
    const updatedOptionsDetails = initialList.map((obj, index) => ({
      ...obj,
      isDisable: index === 2 && !parseData.length ? obj.isDisable : index === 1 ? obj.isDisable : false
    }));
    setOptionsDetails(updatedOptionsDetails);
  }, [showSampleRoomInfoModal]);

  const getSavedProjects = () => {
    setShowSampleRoomInfoModal(!!LocalStorage.get('savedProjects'));
  };

  const optionClickHandler = (index, option) => {
    setModalTitle(option.name);
    if (index === 0) {
      setIsFromSavedProjects(false);
      setShowSampleRoomInfoModal(true);
    } else if (index === 1) {
      setShowFileUpload(true);
    } else if (index === 2) {
      setIsFromSavedProjects(true);
      getSavedProjects();
    }
  };

  const onRoomSelectHandler = (details) => {
    setShowSampleRoomInfoModal(false);
    setShowFileUpload(false);
    props.onSelect(details);
  };

  const handleClose = () => {
    setShowSampleRoomInfoModal(false);
  };
  
  return (
    <div className="visualizer-container">
      <img className="vsl-image" src={VisualisarImg} alt="visualizer" />
      <div className="visualizer-tool mb-2">
        <span className="logo-container">Visualizer</span>
        {optionsDetails.map((opt, index) => (
          <Button
            disabled={opt.isDisable}
            variant="secondary"
            className="button landing-btn"
            key={index}
            onClick={() => optionClickHandler(index, opt)}
          >
            <img src={opt.icon} alt={opt.name} />
            {opt.name}
          </Button>
        ))}
      </div>
      {showSampleRoomInfoModal && 
        <SampleRoomInfoModal
          modalTitle={modalTitle}
          isShow={showSampleRoomInfoModal}
          onPopupClose={handleClose}
          isFromSavedProjects={isFromSavedProjects}
          onSelect={onRoomSelectHandler}
        />
      }
      {showFileUpload && 
        <RoomInMyHouseUpload
          close={setShowFileUpload}
          onSelect={onRoomSelectHandler}
        />
      }
    </div>
  );
}

export default VisualizationOptions;
